function [header signame sRaw tRaw] = read_smart_spice_raw(filename)
%Reads the header and the binary data from file 'filename'.
%File should be created in SmartSpice format.
%header is the entire header, signame is the portion of the header that
%contains a header string and the name of each of the variables on a
%separate line.
%tRaw is a row array of all of the time points
%sRaw is a matrix containing row arrays of all of the signal variables.
%Created by Bob Hay.  v1.00  1/23/2012

%% Data format parameters
sigbytes = 8; %number of bytes in each of the signal data points (8=double)
timebytes = 8;  %number of bytes in each of the time data points
eolchar = hex2dec('0a');  %end of line delimiter
%% Open file
if ~exist(filename, 'file')
%     msg = sprintf('File %s does not exist.', filename);
    error('File %s does not exist.', filename);
end
fid = fopen(filename, 'rb');
[filename, mode, machineformat] = fopen(fid);
%% Read the header
eoh = 0;
linenum = 0;
while(~eoh)%Read the header
    linenum = linenum + 1;
    charnum=0;
    eol = 0;
    while(~eol)
        charnum=charnum+1;
        header(linenum,charnum)= fread(fid, 1, '*uint8');
        eol = (header(linenum,charnum) == eolchar);
    end
    if strfind(char(header(linenum,:)), 'No. Variables:')
        numVarsLineNum = linenum;
    end
    if strfind(char(header(linenum,:)), 'No. Points:')
        numPointsLineNum = linenum;
    end
    eoh = length(strfind(char(header(linenum,:)), 'Binary:'));
    if eoh
        binLineNum = linenum;
    end
end
%% Extract info from the header
numVarsLine = char(header(numVarsLineNum,:));
numvars = str2double(numVarsLine(strfind(numVarsLine, ': ')+1:end));
numPointsLine = char(header(numPointsLineNum,:));
numpoints = str2double(numPointsLine(strfind(numPointsLine, ': ')+1:end));
signame = char(header(binLineNum-numvars:binLineNum -1, :));
%% Read the data
startpos = ftell(fid);  %Save for getting back to the beginning of the binary data
tskipbytes = sigbytes*(numvars-1);   %Number of bytes to skip between each time read
sskipbytes = timebytes + sigbytes*(numvars-2);   %Number of bytes to skip between each signal read
tRaw(1,:) = abs(fread(fid, numpoints, 'double', tskipbytes, machineformat));  %Read the time array
sRaw = zeros(numvars-1,length(tRaw));  %instantiate signal matrix
for signum = 1:numvars-1  %Read all the arrays except for the time array
    fseek(fid, startpos + timebytes + sigbytes*(signum-1), 'bof');    %Back to the beginning, add offset to get to signum voltage
    sRaw(signum, :) = fread(fid, numpoints, 'double', sskipbytes, machineformat); %Read the signals
end
fclose(fid);
% fprintf(1,'Conversion of %d points complete\n', numpoints);

